Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(636)

Unified Diff: runtime/bin/vmservice_dartium.cc

Issue 1042563002: Adjust vmservice_dartium.cc to account for new isolate snapshot buffer name. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/vmservice_dartium.cc
===================================================================
--- runtime/bin/vmservice_dartium.cc (revision 44746)
+++ runtime/bin/vmservice_dartium.cc (working copy)
@@ -24,9 +24,9 @@
-// snapshot_buffer points to a snapshot if we link in a snapshot otherwise
-// it is initialized to NULL.
-extern const uint8_t* snapshot_buffer;
+// isolate_snapshot_buffer points to a snapshot if we link in a snapshot
+// otherwise it is initialized to NULL.
+extern const uint8_t* isolate_snapshot_buffer;
static const char* DEFAULT_VM_SERVICE_SERVER_IP = "127.0.0.1";
static const int DEFAULT_VM_SERVICE_SERVER_PORT = 0;
@@ -42,12 +42,12 @@
Dart_Isolate VmServiceServer::CreateIsolate() {
- ASSERT(snapshot_buffer != NULL);
+ ASSERT(isolate_snapshot_buffer != NULL);
// Create the isolate.
char* error = 0;
Dart_Isolate isolate = Dart_CreateIsolate(DART_VM_SERVICE_ISOLATE_NAME,
"main",
- dart::bin::snapshot_buffer,
+ dart::bin::isolate_snapshot_buffer,
NULL,
&error);
if (!isolate) {
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698